=====
Woger
=====

Workspace manager library

Why woger?
==========

Woger allows you to

- easily create directory structure
- manage multiple versions of your directories
- track the state of each workspace
- transition from one version to another

Documentation
=============

Woger documentation on readthedocs: https://woger.rtfd.io
